	//
//  MetaLocations.swift
//  MetaLocatorSample
//
//  Created by Michael Fatica on 8/19/16.
//  Copyright © 2016 MetaLocator. All rights reserved.
//

import UIKit

class MetaLocations: NSObject {
    
    let name: String
    
    // the contents of the HTML description field
    var desc: String? = ""
    
    var distance: Double?
    
    // the URL in the location `link` field
    var link: String? = ""
    
    // the location image URL
    var image: String? = ""
    
    // the actual image data
    var imageData: UIImage?
    
    // various location attributes
    var address: String? = ""
    var address2: String? = ""
    var city: String? = ""
    var state: String? = ""
    var postalcode: String? = ""
    var country: String? = ""
    var phone: String? = ""
    
    var email: String? = ""
    
    // intialize the location object
    init(name: String, desc: String? = "",distance: Double? = nil,image: String? = "",link: String? = "",address: String? = "",address2: String? = "",city: String? = "",state: String? = "",country: String? = "",phone: String? = "",email: String? = "",postalcode: String? = "") {
        
        self.name = name
        
        self.address = address
        self.address2 = address2
        self.city = city
        self.state = state
        self.postalcode = postalcode
        self.country = country
        
        self.phone = phone
        
        self.distance = distance
        
        self.desc = desc
        self.email = email
        self.image = image
        self.link = link
        
    }
    
    // download the image found in the location.image field and update the imageData property with the actual binary image data
    func pullImage(){
        
        let imageHost:String = "https://admin.metalocator.com"
        
        if let imageURL = self.image {
            
            let imagePath = imageHost + imageURL
            
            let url = NSURL(string: imagePath)
            
            if let data = NSData(contentsOfURL: url!) {
                
                self.imageData = UIImage(data: data)
                
            }
        }

    }
    
    // return this locations distance from the user in a nice language string
    func getFormattedDistance() -> String{
        
        if(self.distance != nil){
            return "\(String(format:"%.0f", self.distance!)) miles away"
        }
        
        return ""
        
    }
    
}
